#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 graphviz
version:              2999.20.2.0
visibility:           public
id:                   graphviz-2999.20.2.0-1cktBBt0lkd9hd5YWWQRhU
key:                  graphviz-2999.20.2.0-1cktBBt0lkd9hd5YWWQRhU
license:              BSD-3-Clause
copyright:            Matthew Sackman, Ivan Lazar Miljenovic
maintainer:           Daniel Casanueva (daniel.casanueva `at` proton.me)
author:               Matthew Sackman, Ivan Lazar Miljenovic
stability:            Beta
homepage:             https://gitlab.com/daniel-casanueva/haskell/graphviz
synopsis:             Bindings to Graphviz for graph visualisation.
description:
    This library provides bindings for the Dot language used by the
    Graphviz (<http://graphviz.org/>) suite of programs for visualising
    graphs, as well as functions to call those programs.

    Main features of the graphviz library include:

    * Almost complete coverage of all Graphviz attributes and syntax.

    * Support for specifying clusters.

    * The ability to use a custom node type.

    * Functions for running a Graphviz layout tool with all specified
    output types.

    * The ability to not only generate but also parse Dot code with two
    options: strict and liberal (in terms of ordering of statements).

    * Functions to convert FGL graphs and other graph-like data structures
    to Dot code - including support to group them into clusters - with a
    high degree of customisation by specifying which attributes to use
    and limited support for the inverse operation.

    * Round-trip support for passing an FGL graph through Graphviz to
    augment node and edge labels with positional information, etc.

category:             Graphs, Graphics
abi:                  810b964dda21382b6bf7a89c67dd9159
exposed:              True
exposed-modules:
    Data.GraphViz Data.GraphViz.Algorithms Data.GraphViz.Attributes
    Data.GraphViz.Attributes.Colors
    Data.GraphViz.Attributes.Colors.Brewer
    Data.GraphViz.Attributes.Colors.SVG
    Data.GraphViz.Attributes.Colors.X11
    Data.GraphViz.Attributes.Complete Data.GraphViz.Attributes.HTML
    Data.GraphViz.Attributes.Internal Data.GraphViz.Commands
    Data.GraphViz.Commands.IO Data.GraphViz.Exception
    Data.GraphViz.Internal.State Data.GraphViz.Internal.Util
    Data.GraphViz.Parsing Data.GraphViz.PreProcessing
    Data.GraphViz.Printing Data.GraphViz.Types
    Data.GraphViz.Types.Canonical Data.GraphViz.Types.Generalised
    Data.GraphViz.Types.Graph Data.GraphViz.Types.Internal.Common
    Data.GraphViz.Types.Monadic

hidden-modules:
    Data.GraphViz.Algorithms.Clustering Data.GraphViz.Attributes.Arrows
    Data.GraphViz.Attributes.ColorScheme Data.GraphViz.Attributes.Same
    Data.GraphViz.Attributes.Values Data.GraphViz.Commands.Available
    Data.GraphViz.Types.State

import-dirs:          /usr/lib/ghc-9.2.8/site-local/graphviz-2999.20.2.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/graphviz-2999.20.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphviz
hs-libraries:         HSgraphviz-2999.20.2.0-1cktBBt0lkd9hd5YWWQRhU
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    colour-2.3.6-GSgSWbXnyNXCwMArJHR09a containers-0.6.5.1
    directory-1.3.6.2 dlist-1.0-HCxoMn9TirQDgPCFxho7O
    fgl-5.8.3.0-KCUJMPY2WFzJs3A1MDEm7T filepath-1.4.2.2 mtl-2.2.2
    polyparse-1.13-I1ahtjDxVhG8wUoxrQsnyB process-1.6.16.0
    temporary-1.3-5DXvPPCb7rKJ7qxYJfJo8P text-1.2.5.0
    wl-pprint-text-1.2.0.2-ExYx00fKP61EY0RvFNPA4y

haddock-interfaces:   /usr/share/doc/haskell-graphviz/html/graphviz.haddock
haddock-html:         /usr/share/doc/haskell-graphviz/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

